@@ -103,7 +103,8 @@ class Element(object):
         self.depends = self._get_element_set(
             os.path.join(path, 'element-deps'))
 
-        logger.debug("New element : %s", str(self))
+        # Uncomment to see all elements and deps listed as they're found
+        # logger.debug("New element : %s", str(self))
 
     def __eq__(self, other):
         return self.name == other.name
@@ -177,7 +178,7 @@ def _expand_element_dependencies(user_elements, all_elements):
         raise MissingOSException("Please include an operating system element")
 
     out = final_elements - provided
-    return([all_elements[element] for element in out])
+    return [all_elements[element] for element in out]
 
 
 def _find_all_elements(paths=None):
@@ -349,5 +350,6 @@ def main():
 
     return 0
 
+
 if __name__ == "__main__":
     main()
